@@ -70,3 +70,13 @@ class zrCurveEntry(iecGroup):
         self.numberOfPoints = len(newZ)
         self.Z = newZ
         self.R = newR
+
+    def uniformIncreasePointsNumber(self,n_points):
+        Z2 = self.Z.pop()
+        Z1 = self.Z.pop()
+        R2 = self.R.pop()
+        R1 = self.R.pop()
+        for i in range(int(n_points)):
+            self.R.append((R2 - R1) / int(n_points) * i + R1)
+            self.Z.append((Z2 - Z1) / int(n_points) * i + Z1)
+        self.numberOfPoints = int(n_points)
